pub enum BoundError {
Count,
Scheme,
Value,
Description,
}Expand description
A violation of the public challenge bounds. No credential content is retained.
Variants
Count
The challenge count is outside 1–8.
Scheme
A scheme is not a lowercase token of at most 64 bytes.
Value
A value is too long or contains a forbidden control byte.
Description
A description is too long or contains a forbidden control byte.