pub fn bisect_file_path(layout: &RepoLayout) -> PathBufExpand description
Convenience: full path to the bisect state file under mkit_dir.
pub fn bisect_file_path(layout: &RepoLayout) -> PathBufConvenience: full path to the bisect state file under mkit_dir.