pub enum CopyDetection {
Off,
On {
level: u8,
threshold: usize,
},
}Expand description
Variants
Off
No cross-file copy detection.
On
Credit a copied block of at least threshold alphanumeric
characters to its origin, searching at the given level.
Implementations
Sourceimpl CopyDetection
impl CopyDetection
Sourcepub const fn git_default(level: u8) -> Self
pub const fn git_default(level: u8) -> Self
git’s default -C at the given level (threshold 40).