pub struct GcReport {
pub scanned: usize,
pub live: usize,
pub kept_recent: usize,
pub pruned: usize,
pub bytes_reclaimed: u64,
pub dry_run: bool,
}Expand description
Outcome of a run_gc sweep.
Fields
scanned: usizeObjects examined in the store.
live: usizeObjects retained because they are reachable from a root.
kept_recent: usizeUnreachable objects retained anyway — within the grace window, or whose age could not be determined (kept fail-safe).
pruned: usizeUnreachable objects pruned (or that would be pruned in a dry run).
bytes_reclaimed: u64Bytes reclaimed by the pruned objects.
dry_run: boolTrue if this was a dry run (nothing deleted).