pub enum RebaseAction {
Pick,
Reword,
Squash,
Fixup,
}Expand description
What to do with a commit when it is replayed during an interactive
rebase. Non-interactive rebase uses RebaseAction::Pick for every
commit. (drop is represented by omitting the commit from the todo.)
Variants
Pick
Replay the commit unchanged (default).
Reword
Replay the commit, then open the editor to rewrite its message.
Squash
Fold the commit into the previous one, combining their messages (the editor opens on the combined message).
Fixup
Fold the commit into the previous one, discarding this commit’s message (the previous message is kept).
Implementations
Sourceimpl RebaseAction
impl RebaseAction
Sourcepub fn folds_into_previous(self) -> bool
pub fn folds_into_previous(self) -> bool
true for actions that fold into the previous commit rather than
creating a new one on top of it.
Sourcepub fn from_keyword(s: &str) -> Option<Self>
pub fn from_keyword(s: &str) -> Option<Self>
Parse an action from its persisted keyword.