pub struct RestoreOptions {
pub clean: bool,
pub sparse_patterns: Option<Vec<SparsePattern>>,
}Expand description
Options for restore_tree.
Fields
clean: boolIf true, delete anything in the target dir that is not in the
tree (preserving .mkit/ and .git/). Default true.
sparse_patterns: Option<Vec<SparsePattern>>If Some, only restore entries whose path matches the patterns.
Implementations