#[non_exhaustive]pub enum CommitOutcome {
Advanced(AdvanceOutcome),
TicketRejected,
DeltaBaseUnavailable,
PacklistNotInRepository,
}Expand description
Result of an advance that can consume upload tickets.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Advanced(AdvanceOutcome)
The advance reached the ordinary two-ref outcome.
TicketRejected
A ticket was invalid, expired, incomplete, or was already consumed.
A delta base is not yet available to this repository.
PacklistNotInRepository
The packlist names content not in this repository.