pub enum RefWriteCondition {
Any,
Missing,
Match(Hash),
}Expand description
CAS condition for update_ref.
Variants
Any
Unconditional write — clobbers any existing value.
Missing
Write only if the ref does not currently exist.
Match(Hash)
Write only if the ref currently contains this exact hash.