pub fn delete_ref_safe(layout: &RepoLayout, branch: &str) -> RefResult<()>Expand description
Delete a branch ref unless it is the currently checked-out branch.
pub fn delete_ref_safe(layout: &RepoLayout, branch: &str) -> RefResult<()>Delete a branch ref unless it is the currently checked-out branch.