#[non_exhaustive]pub enum PartError {
PartSizeNotPowerOfTwo,
PartSizeTooSmall,
NotMultipart,
TooManyParts,
IndexOutOfRange,
Overrun,
LengthMismatch,
WrongPartCount,
}Expand description
A part geometry or part stream that violates SPEC-TRANSPORT-CONNECT 7.6.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
PartSizeNotPowerOfTwo
part_size is not a power of two.
PartSizeTooSmall
part_size is below MIN_PART_SIZE.
NotMultipart
The pack fits one part, so it uploads with UploadPack, never parts.
TooManyParts
The upload needs more parts than allowed.
IndexOutOfRange
A part index at or beyond the part count.
Overrun
More bytes than the part’s expected length.
LengthMismatch
Fewer bytes than the part’s expected length.
WrongPartCount
A merge given a chaining value count other than the part count.