#[non_exhaustive]pub struct Plan {
pub kind: RangeProofKind,
pub first: usize,
pub last: usize,
pub needed_chunk_indices: Vec<usize>,
}Expand description
Pure prefetch plan for a chunked file. needed_chunk_indices contains
every preceding chunk needed for absolute length proofs and each span
chunk, in ascending order.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.kind: RangeProofKindProof format the range requires.
first: usizeIndex of the chunk containing the first requested byte.
last: usizeIndex of the chunk containing the last requested byte.
needed_chunk_indices: Vec<usize>Every chunk index that must be read: 0..=last.