pub fn encode_sparse_response(
resp: &SparseResponse,
) -> Result<Vec<u8>, SparseWireError>Expand description
The wire contains only the root, filter commitment and full tree witness.
Delivered entries are derived from that witness by verify_sparse consumers.